@@ -26,17 +26,13 @@ from typing import (
     # cast,
     Optional,
 )
-
-from .config import (
-    logging
-)
+import logging
 
 # pylint:disable=R0401
 if TYPE_CHECKING:
-    from wechaty_puppet import Puppet
+    from wechaty_puppet import Puppet   # type: ignore
     from .wechaty import Wechaty
 
-
 log = logging.getLogger('Accessory')
 
 
@@ -46,7 +42,7 @@ class Accessory:
     See: https://github.com/wechaty/wechaty/blob/master/src/accessory.ts
     """
 
-    _puppet : Optional[Puppet]  = None
+    _puppet: Optional[Puppet] = None
     _wechaty: Optional[Wechaty] = None
 
     @classmethod
